import 'zone.js/node';

import { APP_BASE_HREF } from '@angular/common';
import { ngExpressEngine } from '@nguniversal/express-engine';
import * as express from 'express';
import * as compression from 'compression';
import { existsSync } from 'node:fs';
import { join } from 'node:path';
import { AppServerModule } from './src/main.server';
import {REQUEST, RESPONSE} from "./src/app/openaireLibrary/utils/tokens";
var bodyParser = require('body-parser')
var jsonParser = bodyParser.json()
import * as fs from 'fs';
import {readFileSync} from "fs";
import {properties} from "./src/environments/environment";
// The Express app is exported so that it can be used by serverless Functions.
export function app(): express.Express {
  const server = express();
  server.use(compression());
  const distFolder = join(process.cwd(), 'dist/irish-monitor/browser');
  const indexHtml = existsSync(join(distFolder, 'index.original.html')) ? 'index.original.html' : 'index';

  // Our Universal express-engine (found @ https://github.com/angular/universal/tree/main/modules/express-engine)
  server.engine('html', ngExpressEngine({
    bootstrap: AppServerModule,
    inlineCriticalCss: false
  }));

  server.set('view engine', 'html');
  server.set('views', distFolder);

  // Example Express Rest API endpoints
  // server.get('/api/**', (req, res) => { });
  // Serve static files from /browser

  server.get('/public-logs/:year/:month', (req, res) => {
    let today = new Date();
    let filename = getFileName(req.params['year'], req.params['month'])
    res.setHeader('content-disposition','attachment; filename='+filename);
    let file = " ";
    try {
      file = readFileSync(properties.logFilesPath + filename, 'utf-8');
    }catch (e){}
    res.status(200).send( file);
  });
  server.post('/logAction',  jsonParser,(req, res) => {
    let log = req.body;
    log.date = new Date();
    let filename = getFileName(log.date.getFullYear(), log.date.getMonth()+1);
    fs.appendFile(properties.logFilesPath + filename, formatPrettyLog(log)+ "\n", 'utf8', function(err) {
      if (err) {
        console.error(err);
        return console.error(err);
      }
    });
    res.status(200).send({
      code: 200,
      message: 'action received!'
    });
  });
  server.get('*.*', express.static(distFolder, {
    maxAge: '1y'
  }));

  // All regular routes use the Universal engine
  server.get('*', (req, res) => {
    res.render(indexHtml, {
          req, providers: [
            {
              provide: APP_BASE_HREF,
              useValue: req.baseUrl
            },
            {
              provide: REQUEST, useValue: (req)
            },
            {
              provide: RESPONSE, useValue: (res)
            }
          ]
        }
    );
  });


  return server;
}

function run(): void {
  const port = process.env['PORT'] || 4000;

  // Start up the Node server
  const server = app();
  server.listen(port, () => {
    console.log(`Node Express server listening on http://localhost:${port}`);
  });
}

function getFileName(year, month){
  return 'actions' + (year && month ? "_" + year + "_" + month : "")+".log";
}
function formatPrettyLog(log){
  return "On " + (log.date ? formatDateAndTime(log.date) : "") + " "  /*+ logs[i].action + " "*/ + log.message + "<br>";
}
function formatDateAndTime(dateStr){
  let date = new Date(dateStr);
  const formatter = new Intl.DateTimeFormat('en-GB', {

    timeStyle: 'short',
    timeZone: 'GMT',
  });
  return date.getDate() + "/" + (date.getMonth() + 1) + "/" + date.getFullYear() + " "
    + formatter.format(date) + "";

}

// Webpack will replace 'require' with '__webpack_require__'
// '__non_webpack_require__' is a proxy to Node 'require'
// The below code is to ensure that the server is run only when not requiring the bundle.
declare const __non_webpack_require__: NodeRequire;
const mainModule = __non_webpack_require__.main;
const moduleFilename = mainModule && mainModule.filename || '';
if (moduleFilename === __filename || moduleFilename.includes('iisnode')) {
  run();
}

export * from './src/main.server';
