import {NgModule} from "@angular/core";
import {CommonModule} from "@angular/common";
import {RouterModule} from "@angular/router";
import {AdminComponent} from "./admin.component";
import {HelperFunctions} from "../openaireLibrary/utils/HelperFunctions.class";
import {SideBarModule} from "../openaireLibrary/dashboard/sharedComponents/sidebar/sideBar.module";
import {LoadingModule} from "../openaireLibrary/utils/loading/loading.module";
import {LogoUrlPipeModule} from "../openaireLibrary/utils/pipes/logoUrlPipe.module";

@NgModule({
  imports: [CommonModule, RouterModule.forChild([
    {
      path: '', component: AdminComponent, children: [
        {
          path: '',
          loadChildren: () => import('../openaireLibrary/monitor-admin/manageStakeholders/manageStakeholders.module').then(m => m.ManageStakeholdersModule)
        },
        {
          path: ':alias', children: [
            {
              path: '',
              loadChildren: () => import('../openaireLibrary/monitor-admin/general/general.module').then(m => m.GeneralModule)
            },
            {
              matcher: HelperFunctions.routingMatcher(['indicators', 'indicators/:topic']),
              loadChildren: () => import('../openaireLibrary/monitor-admin/topic/topic.module').then(m => m.TopicModule),
              data: {hasInternalSidebar: true, showLogo: true},
              pathMatch: 'full'
            },
            {
              path: 'users',
              redirectTo: 'users/manager',
              pathMatch: 'full'
            },
            {
              path: 'users/manager',
              loadChildren: () => import('./users/users.module').then(m => m.UsersModule),
              pathMatch: 'full'
            },
          ]
        }
      ]
    }
  ]), SideBarModule, LoadingModule, LogoUrlPipeModule],
  declarations: [AdminComponent],
  exports: [AdminComponent]
})
export class AdminModule {

}
