import {ChangeDetectorRef, Component, OnInit} from '@angular/core';
import {ActivatedRoute, Router} from "@angular/router";
import {MenuItem} from "./openaireLibrary/sharedComponents/menu";
import {Header} from "./openaireLibrary/sharedComponents/navigationBar.component";
import {ConfigurationService} from "./openaireLibrary/utils/configuration/configuration.service";
import {Irish} from "./shared/irish";
import {CustomFilterService} from "./openaireLibrary/shared/customFilter.service";
import {UserManagementService} from "./openaireLibrary/services/user-management.service";
import {Session, User} from "./openaireLibrary/login/utils/helper.class";
import {SmoothScroll} from "./openaireLibrary/utils/smooth-scroll";
import {LayoutService} from "./openaireLibrary/dashboard/sharedComponents/sidebar/layout.service";
import {StakeholderUtils} from "./openaireLibrary/monitor-admin/utils/indicator-utils";
import {ResearcherBaseComponent} from "./shared/researcher-base.component";
import {UserProfileService} from "./openaireLibrary/services/userProfile.service";
import {SearchOrcidService} from "./openaireLibrary/claims/claim-utils/service/searchOrcid.service";
import {SearchResearchResultsService} from "./openaireLibrary/services/searchResearchResults.service";
import {Identifier} from "./openaireLibrary/utils/string-utils.class";

@Component({
  selector: 'app-root',
  template: `
      <div *ngIf="loading">
          <loading [full]="true"></loading>
      </div>
      <div *ngIf="!loading" class="uk-background-default">
          <navbar *ngIf="hasHeader" portal="irish_monitor" [menuItems]="menuItems" [showMenu]="true"
                  [header]="header" [user]="user" [userMenuItems]="userMenuItems"></navbar>
          <div [ngClass]="rootClass">
              <div id="modal-container"></div>
              <main>
                  <router-outlet></router-outlet>
              </main>
          </div>
      </div>
      <cookie-law *ngIf="isClient" position="bottom" cookieName="cookieLawSeen-NOAMIreland">
          National Open Access Monitor - Ireland, uses cookies in order to function properly.<br>
          Cookies are small pieces of data that websites store in your browser to allow us to give you the best browsing
          experience possible.
          By using the National Open Access Monitor - Ireland portal you accept our use of cookies. <!--<a
          href="https://www.openaire.eu/privacy-policy#cookies" target="_blank"> Read more <span class="uk-icon">
            <svg width="20" height="20" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg" icon="chevron-right"
                 ratio="1"><polyline fill="none" stroke="#000" stroke-width="1.03"
                                     points="7 4 13 10 7 16"></polyline></svg>
            </span></a>-->
      </cookie-law>
      <!--<cookie-law *ngIf="isClient" position="top" cookieName="logActions-NOAMIreland">
        National Open Access Monitor - Ireland, creates public logs for user actions.<br>
        By using the National Open Access Monitor - Ireland portal you consent to log your actions <a
         routerLink="/public-logs"> View Public logs <span class="uk-icon">
            <svg width="20" height="20" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg" icon="chevron-right"
                 ratio="1"><polyline fill="none" stroke="#000" stroke-width="1.03"
                                     points="7 4 13 10 7 16"></polyline></svg>
            </span></a>
      </cookie-law>-->
  `
})
export class AppComponent extends ResearcherBaseComponent implements OnInit {
  loading: boolean = false;
  hasHeader: boolean = true;
  rootClass: string;
  header: Header = {
    route: "/",
    title: "Noami",
    logoUrl: 'assets/logo/main.svg',
    logoSmallUrl: 'assets/logo/small.svg',
    position: 'left',
    badge: true,
  };
  menuItems: MenuItem[] = [];
  userMenuItems: MenuItem[] = [];
  irish: Irish = new Irish();
  user: User;
  isClient: boolean = false;
  stakeholderUtils: StakeholderUtils = new StakeholderUtils();

  constructor(protected _route: ActivatedRoute,
              protected _router: Router,
              protected cdr: ChangeDetectorRef,
              private layoutService: LayoutService,
              private smoothScroll: SmoothScroll,
              private configurationService: ConfigurationService,
              private customFilterService: CustomFilterService,
              private userManagementService: UserManagementService,
              private userProfileService:UserProfileService,
              protected _searchOrcidService: SearchOrcidService,
              protected _searchResearchResultsService: SearchResearchResultsService
  ) {
    super();
    this.configurationService.initStaticPortal(this.irish.portal);
    this.userManagementService.fixRedirectURL = this.properties.afterLoginRedirectLink;
  }

  ngOnDestroy() {
    super.ngOnDestroy();
    this.customFilterService.clearSubscriptions();
    this.configurationService.clearSubscriptions();
    this.smoothScroll.clearSubscriptions();
    this.userProfileService.clearSubscriptions();
  }

  ngOnInit() {
    this.isClient = typeof document !== 'undefined';
    this.subscriptions.push(this.userManagementService.getUserInfo().subscribe(user => {
      this.user = user;
      if(user){
        this.userProfileService.initUserProfile()
      }else{
        this.userProfileService.setUserProfile(null);
      }
      this.initialize();
    }));
    this.subscriptions.push(this.layoutService.rootClass.subscribe(rootClass => {
      if(rootClass && this.isClient) {
        let link = <HTMLLinkElement>document.getElementById('theme');
        let append = false;
        if(!link) {
          link = document.createElement('link');
          link.rel = 'stylesheet';
          link.id = 'theme';
          append = true;
        }
        link.href = rootClass + '.css';
        link.onerror = (error) => console.log(error);
        if(append) {
          document.head.appendChild(link);
        }
      }
      this.rootClass = rootClass;
      this.cdr.detectChanges();
    }));

  }

  initialize() {
    this.menuItems = [
      new MenuItem("national", this.stakeholderUtils.entities.country + ' ' + this.stakeholderUtils.entities.stakeholder, "", "/", false, [], null, {}, null, null, null),
      new MenuItem("rpo", this.stakeholderUtils.entities.organization + ' ' + this.stakeholderUtils.entities.stakeholders, "", "/rpo", false, [], null, {}, null, null, null, "/rpo"),
      new MenuItem("rfo", this.stakeholderUtils.entities.funder + ' ' + this.stakeholderUtils.entities.stakeholders, "", "/rfo", false, [], null, {}, null, null, null, "/rfo"),
      new MenuItem("researcher", "Researcher Monitors", "", "/researcher", false, [], null, {}, null, null, null, "/researcher"),
      new MenuItem("repository", "Repository Monitors", "", "/repository", false, [], null, {}, null, null, null, "/repository"),
      new MenuItem("resources", "Resources", "", "", false, [], null, {}, null, null, null,
        "/resources","_blank", "internal", false, [new MenuItem("public-logs", "Public logs", "", "/public-logs", false, [], null, {}, null, null, null, "/public-logs")]),
    ];
    if (this.user) {
      this.userMenuItems = [];
      // this.user.orcid = '0000-0003-4768-182X';
      if(this.user.orcid) {
        this.authorId = Identifier.getRawORCID(this.user.orcid);
        this.results = {
          success: (res: string | number) => {
            if(+res > 0) {
              this.userMenuItems.push(new MenuItem("my-researcher", "My Researcher Monitor", "", "/researcher/" + this.authorId, false, [], null, {}, null, null, null, null));
              this.staticUserItems();
            }else{
              this.staticUserItems();
            }
          }
        }
        this.search();
      } else {
        this.staticUserItems();
      }
    }
  }

  staticUserItems() {
    this.userMenuItems.push(
        new MenuItem("myorcidlinks", "My Orcid links", "", "/my-orcid-links", false, [], null, {}, null, null, null, null),
        new MenuItem("myclaims", "My links", "", "/participate/myclaims", false, [], null, {}, null, null, null, null),
        new MenuItem("claims", "Link", "", "/participate/claim", false, [], null, {}, null, null, null, null),
        new MenuItem("upload-dois", "Upload DOIs", "", "/upload-dois", false, [], null, {}, null, null, null, null)
    );
    if (this.isAdmin) {
      this.userMenuItems.push(new MenuItem("stakeholders", "Manage profiles", "", "/admin", false, [], [], {}, {name: 'settings'}));
    }
  }

  public get isAdmin() {
    return Session.isPortalAdministrator(this.user) || Session.isMonitorCurator(this.user);
  }
}
