import {Component, OnInit, ViewChild} from '@angular/core';
import {ActivatedRoute, Router} from '@angular/router';
import {EmailService} from "../openaireLibrary/utils/email/email.service";
import {Composer} from "../openaireLibrary/utils/email/composer";
import {Meta, Title} from "@angular/platform-browser";
import {PiwikService} from "../openaireLibrary/utils/piwik/piwik.service";
import {SEOService} from "../openaireLibrary/sharedComponents/SEO/SEO.service";
import {UntypedFormBuilder, UntypedFormGroup, Validators} from "@angular/forms";
import {NotificationHandler} from "../openaireLibrary/utils/notification-handler";
import {BaseComponent} from '../openaireLibrary/sharedComponents/base/base.component';

@Component({
    selector: 'contact',
    templateUrl: './contact.component.html'
})
export class ContactComponent extends BaseComponent implements OnInit {
    // public url: string = null;
    public sending = false;
    public contactForm: UntypedFormGroup;
    // @ViewChild('fsModal') fsModal;
    @ViewChild('modal') modal;
    
    constructor(protected _route: ActivatedRoute,
                protected _router: Router,
                protected _title: Title,
                protected _meta: Meta,
                protected _piwikService: PiwikService,
                protected seoService: SEOService,
                private emailService: EmailService,
                private fb: UntypedFormBuilder) {
      super();
    }
    
    ngOnInit() {
      // this.title = 'Contact us';
      // this.description = 'Contact us';
      // this.url = this.properties.domain + this.properties.baseLink + this._router.url;
      // this.setMetadata();
      this.reset();
    }

    public send(event) {
      if(event.valid === true) {
        this.sendMail(this.properties.admins);
      }
    }

    public reset() {
      this.contactForm = this.fb.group( {
        name: this.fb.control('', Validators.required),
        email: this.fb.control('', [Validators.required, Validators.email]),
        subject: this.fb.control('', Validators.required),
        message: this.fb.control('', Validators.required),
        recaptcha: this.fb.control('', Validators.required),
      });
    }
    
    private sendMail(admins: any) {
      this.sending = true;
      this.subscriptions.push(this.emailService.contact(this.properties,
        Composer.composeEmailforIrishMonitor(this.contactForm.value, admins),
        this.contactForm.value.recaptcha).subscribe(
        res => {
          if (res) {
            this.sending = false;
            this.reset();
            this.modalOpen();
          } else {
            this.handleError('Email <b>sent failed!</b> Please try again.');
          }
        },
        error => {
          this.handleError('Email <b>sent failed!</b> Please try again.', error);
        }
      ));
    }

    public modalOpen() {
      this.modal.okButton = true;
      this.modal.alertTitle = 'Your request has been successfully submitted';
      this.modal.alertMessage = false;
      this.modal.cancelButton = false;
      this.modal.okButtonLeft = false;
      this.modal.okButtonText = 'OK';
      this.modal.open();
    }

    handleError(message: string, error = null) {
      if(error) {
          console.error(error);
      }
      NotificationHandler.rise(message, 'danger');
      this.sending = false;
      this.contactForm.get('recaptcha').setValue('');
    }

    public goToHome() {
      this._router.navigate(['/']);
    }
}
