import {ChangeDetectorRef, Directive, OnInit} from "@angular/core";
import {StakeholderBaseComponent} from "../openaireLibrary/monitor-admin/utils/stakeholder-base.component";
import {Stakeholder, StakeholderType} from "../openaireLibrary/monitor/entities/stakeholder";
import {Option} from "../openaireLibrary/sharedComponents/input/input.component";
import {FormBuilder, FormControl} from "@angular/forms";
import {debounceTime, distinctUntilChanged} from "rxjs/operators";
import {HelperFunctions} from "../openaireLibrary/utils/HelperFunctions.class";
import {StakeholderService} from "../openaireLibrary/monitor/services/stakeholder.service";
import {LayoutService} from "../openaireLibrary/dashboard/sharedComponents/sidebar/layout.service";

@Directive()
export class BrowseStakeholderBaseComponent extends StakeholderBaseComponent implements OnInit {
  stakeholderType: StakeholderType;
  stakeholders: Stakeholder[] = [];
  filteredStakeholders: Stakeholder[] = [];
  showLoading: boolean = true;
  isMobile: boolean = false;

  gridView: boolean = true;
  sortOptions: Option[] = [
    {value: 'alphAsc', label: 'Alphabetically Asc. (A-Z)'},
    {value: 'alphDsc', label: 'Alphabetically Dsc. (Z-A)'},
    {value: 'oaDsc', label: '"Open Access %" Dsc.'}
  ];
  pageOptions: number[] = [10, 20, 30, 40];
  sortBy: string = 'alphAsc';
  currentPage: number = 1;
  pageSize: number = 10;
  parameters = {};
  keywordControl: FormControl;

  /* Services */
  protected stakeholderService: StakeholderService;
  protected layoutService: LayoutService;
  protected cdr: ChangeDetectorRef;
  protected fb: FormBuilder;

  constructor() {
    super();
  }

  ngOnInit() {
    this.keywordControl = this.fb.control(this._route.snapshot.queryParams.keyword);
    this.subscriptions.push(this.layoutService.isMobile.subscribe(isMobile => {
      this.isMobile = isMobile;
      this.cdr.detectChanges();
    }));
    this.stakeholderType = this._route.snapshot.data.type;
    if(!this.stakeholderType) {
      this.navigateToError();
    }
    this.subscriptions.push(this.stakeholderService.getStakeholders(this.properties.monitorServiceAPIURL, this.stakeholderType).subscribe(stakeholders => {
      this.stakeholders = stakeholders;
      this.filteredStakeholders = stakeholders;
      this.filteredStakeholders.sort((a, b) => a['name'].localeCompare(b['name']));
      this.filtering(this.keywordControl.value);
    }));
    this.subscriptions.push(this.keywordControl.valueChanges.pipe(debounceTime(200), distinctUntilChanged()).subscribe(value => {
      this.filtering(value);
      if(value?.length > 0) {
        this.parameters['keyword'] = value;
      } else {
        delete this.parameters['keyword']
      }
      this._router.navigate([], {queryParams: this.parameters});
    }));
  }

  private filtering(value) {
    if(!value){
      this.filteredStakeholders = this.stakeholders;
    } else {
      this.filteredStakeholders = this.stakeholders.filter(item => (item['name'] && item['name'].toLowerCase().includes(value.toLowerCase())) || (item['alias'] && item['alias'].toLowerCase().includes(value.toLowerCase())));
    }
    this.afterStakeholdersInitialized();
    this.currentPage = 1;
  }

  sortByChanged() {
    switch(this.sortBy) {
      case 'alphAsc':
        this.stakeholders = this.stakeholders.sort((a, b) => a['name'].localeCompare(b['name']));
        break;
      case 'alphDsc':
        this.stakeholders = this.stakeholders.sort((a, b) => b['name'].localeCompare(a['name']));
        break;
      case 'oaDsc':
        // TODO: dont have an OA percentage yet
        // this.stakeholders = this.stakeholders.sort((a, b) => b['openAccessPercentage'] - a['openAccessPercentage']);
        break;
      default:
        break;
    }
  }

  sizeChanged($event) {
    this.pageSize = $event;
    this.currentPage = 1;
    this.afterStakeholdersInitialized();
  }

  updateCurrentPage($event) {
    this.currentPage = $event.value;
    HelperFunctions.scrollToId('target');
    this.afterStakeholdersInitialized();
  }

  get typeAsLabel() {
    return this.stakeholderUtils.types.find(type => type.value === this.stakeholderType).label;
  }
  
  afterStakeholdersInitialized() {
    // this is a method that will be overriden from the components extending this base component, if needed
    this.showLoading = false;
  }
}
